package gpsys.cos;

import gpsys.*;


/**
 * <pre>
 *	Vector2Mod10	AddVector2Mod10(Vector2Mod10 v1, Vector2Mod10 v2)
 * </pre>
 *
 * A Function that adds two Vector2Mod10 quantities and returns the result.
 *
 * @version             1.1, 24 Mars 1999
 * @author      <a href="mailto:epierre@e-nef.com">Emmanuel PIERRE</a>
 *                      <address>DEA IARFA,</address>
 * @see gpsys.Primitive
 * @see gpsys.Function
 *
 */
public class AddVector2Mod10 extends Function {

	/**
	 * Create a Vector2Mod10 adder object.
	 */
	public AddVector2Mod10() {
		this.type = CosSimTypes.Vector2Mod10;
		argTypes = new Type[2];
		argTypes[0] = type;
		argTypes[1] = type;
	}

	/**
	 * Evaluate the ADF as one that return an Object (this is necessary since
	 * the evaluation actually returns a Vector2Mod10 object).
	 *
	 * @param i	The individual being evaluated.
	 * @param arguments	The Gene trees representing the arguments to be
	 *					added.
	 * @return	An Object reference, which is the result of adding the two
	 *			Vector2Mod10 arguments.
	 * @exception	EvaluationException	If there is an evaluation failure.
	 */
	public final Object evaluateObject(Individual i, Gene[] arguments)
	throws EvaluationException {
		return Vector2Mod10.add(
			 (Vector2Mod10) arguments[0].evaluateObject(i),
			 (Vector2Mod10) arguments[1].evaluateObject(i));
	}

	/**
	 * Creates an instance of this Function.
	 *
	 * @return	A reference to this same Object since none of the instance
	 *			variables will ever be changed.	
	 */
	public final Primitive instance() {
		return this;
	}

	/**
	 * Returns a String representation of this Function.
	 *
	 * @return A String containing the name of the Function.
	 */
	public String toString() {
		return "AddVector2Mod10";
	}
}
